summaryrefslogtreecommitdiff
path: root/examples/rpc_async.py
diff options
context:
space:
mode:
Diffstat (limited to 'examples/rpc_async.py')
-rwxr-xr-xexamples/rpc_async.py10
1 files changed, 5 insertions, 5 deletions
diff --git a/examples/rpc_async.py b/examples/rpc_async.py
index e3e23b69..f773a8d1 100755
--- a/examples/rpc_async.py
+++ b/examples/rpc_async.py
@@ -1,15 +1,15 @@
-#!/usr/bin/env python
+#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
SleekXMPP: The Sleek XMPP Library
Copyright (C) 2011 Dann Martens
- This file is part of SleekXMPP.
+ This file is part of Slixmpp.
See the file LICENSE for copying permission.
"""
-from sleekxmpp.plugins.xep_0009.remote import Endpoint, remote, Remote, \
+from slixmpp.plugins.xep_0009.remote import Endpoint, remote, Remote, \
ANY_ALL, Future
import time
@@ -20,7 +20,7 @@ class Boomerang(Endpoint):
@remote
def throw(self):
- print "Duck!"
+ print("Duck!")
@@ -1,15 +1,15 @@
# -*- coding: utf-8 -*-
"""
- SleekXMPP: The Sleek XMPP Library
+ Slixmpp: The Slick XMPP Library
Copyright (C) 2011 Dann Martens